% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot_break_down.R
\name{plot.break_down}
\alias{plot.break_down}
\title{Plot Generic for Break Down Objects}
\usage{
\method{plot}{break_down}(x, ..., baseline = NA, max_features = 10,
  min_max = NA, vcolors = DALEX::theme_drwhy_colors_break_down(),
  digits = 3, rounding_function = round, add_contributions = TRUE,
  shift_contributions = 0.05, plot_distributions = FALSE)
}
\arguments{
\item{x}{the model model of `break_down` class.}

\item{...}{other parameters.}

\item{baseline}{if numeric then veritical line starts in `baseline`.}

\item{max_features}{maximal number of features to be included in the plot. default value is 4.}

\item{min_max}{a range of OX axis. By deafult `NA` therefore will be extracted from the contributions of `x`. But can be set to some constants, usefull if these plots are used for comparisons.}

\item{vcolors}{named vector with colors.}

\item{digits}{number of decimal places (`round`) or significant digits (`signif`) to be used.
See the \code{rounding_function} argument.}

\item{rounding_function}{function that is to used for rounding numbers.
It may be \code{\link{signif}} which keeps a specified number of significant digits.
Or the default \code{\link{round}} to have the same precision for all components.}

\item{add_contributions}{shall variable contributions to be added the the plot?}

\item{shift_contributions}{how much labels sholud be shifted right as a fraction of range. By default 0.05}

\item{plot_distributions}{if `TRUE` then distributions of conditional propotions will be plotted. This requires \code{keep_distributions=TRUE} in the
\code{\link{break_down}}, \code{\link{local_attributions}}, or \code{\link{local_interactions}}.}
}
\value{
a `ggplot2` object.
}
\description{
Plots waterfall break down for objects of the `break_down` class.
Usually executed after `break_down()` function, `local_attributions()` or `local_interactions()`.
}
\examples{
library("DALEX")
library("iBreakDown")
# Toy examples, because CRAN angels ask for them
titanic <- na.omit(titanic)
set.seed(1313)
titanic_small <- titanic[sample(1:nrow(titanic), 500), c(1,2,6,9)]
model_titanic_glm <- glm(survived == "yes" ~ gender + age + fare,
                       data = titanic_small, family = "binomial")
explain_titanic_glm <- explain(model_titanic_glm,
                           data = titanic_small[,-9],
                           y = titanic_small$survived == "yes")
bd_rf <- break_down(explain_titanic_glm, titanic_small[1, ])
bd_rf
plot(bd_rf, max_features = 3)

\donttest{
## Not run:
library("randomForest")
set.seed(1313)
# example with interaction
# classification for HR data
model <- randomForest(status ~ . , data = HR)
new_observation <- HR_test[1,]

explainer_rf <- explain(model,
                        data = HR[1:1000,1:5],
                        y = HR$status[1:1000])

bd_rf <- local_attributions(explainer_rf,
                           new_observation)
bd_rf
plot(bd_rf)
plot(bd_rf, baseline = 0)
plot(bd_rf, min_max = c(0,1))

bd_rf <- local_attributions(explainer_rf,
                           new_observation,
                           keep_distributions = TRUE)
bd_rf
plot(bd_rf, plot_distributions = TRUE)

bd_rf <- local_interactions(explainer_rf,
                 new_observation,
                 keep_distributions = TRUE)

bd_rf
plot(bd_rf)
plot(bd_rf, plot_distributions = TRUE)

# example for regression - apartment prices
# here we do not have intreactions
model <- randomForest(m2.price ~ . , data = apartments)
explainer_rf <- explain(model,
                        data = apartments_test[1:1000,2:6],
                        y = apartments_test$m2.price[1:1000])

bd_rf <- local_attributions(explainer_rf,
                           apartments_test[1,])
bd_rf
plot(bd_rf, digits = 1)
plot(bd_rf, digits = 1, baseline = 0)

bd_rf <- local_attributions(explainer_rf,
                           apartments_test[1,],
                           keep_distributions = TRUE)
plot(bd_rf, plot_distributions = TRUE)

bd_rf <- local_interactions(explainer_rf,
                 new_observation = apartments_test[1,],
                 keep_distributions = TRUE)

bd_rf
plot(bd_rf)
plot(bd_rf, plot_distributions = TRUE)
}
}
\references{
Predictive Models: Visual Exploration, Explanation and Debugging \url{https://pbiecek.github.io/PM_VEE}
}
